==> SCA_SQL_18.16.01.zip: sp2A_criarlistapendencia.sql <==
drop procedure sp2_criarlistapendencia 
go
create PROCEDURE sp2_criarlistapendencia 
--@nResto int 
AS
BEGIN
DECLARE  @MAXLIST INTEGER
DECLARE  @QTDELIST INTEGER
DECLARE  @QTDE_IN_LISTA INTEGER
DECLARE  @rstatus CHAR(1)
DECLARE @ERR INT


--	if @nResto = 1
--		return
		
	exec TELESSVR.sql_logenvon2A	
	SET @MAXLIST = 85
	SET LOCK_TIMEOUT 2000
	update pend_on002ON set status = '4' 
		where (status = '2' or status = '4') and data_ini + ( 1 / 24 / 60 )  < getdate() 

	DECLARE SOBJ CURSOR FOR (
		select distinct p.end_ip, p.qtd_livre, p.status , d.atuforc, d.datforc
		from 
			PEND_ON002ON p, DAT07 d 
		where 
			--(CAST (SUBSTRING (p.end_ip, 13, 3) AS INT) % 2) = @nResto and 
			p.end_ip = d.end_ip and 
			p.status = '0' and 
			p.qtd_livre > 0 and
			( exists ( select top 1 1 from pend_on001 where end_ip = p.end_ip and tipo_atu = '1' and status = '0' )
			or exists ( select top 1 1 from pend_on003 where end_ip = p.end_ip)))

	declare @Vend_ip char(15)
	declare @Vqtd_livre integer
	declare @Vstatus char(1)
	declare @Vatuforc char(1)
	declare @Vdatforc datetime


	OPEN SOBJ
	fetch next from SOBJ into @Vend_ip ,@Vqtd_livre ,@Vstatus ,@Vatuforc ,@Vdatforc 
	while (@@fetch_status <> -1)
	begin
		--begin transaction t2
		set @QTDE_IN_LISTA = (select count(*) from pend_on003 where end_ip = @VEND_IP)
		if @QTDE_IN_LISTA > 0 
		begin
			update pend_on002ON set status = '1' where end_ip = @VEND_IP
			select @ERR = @@ERROR
			GOTO Main_Loop 
		end
    	if @Vqtd_livre < @MAXLIST
        	set @QTDELIST = @Vqtd_livre 
		else
    	    set @QTDELIST = @MAXLIST
	
		set rowcount @QTDELIST
		insert into tmp_listapendencia ( end_ip, numserial, identif )
		select 
			@VEND_IP as end_ip,         
			numserial, 
			identif
		from 
		   (select
			   top 85
			   numserial, 
			   max( identif ) as identif,
			   min( identif ) as minidentif
		   from 
			   pend_on001 
		   where 
			   end_ip = @VEND_IP and
			   status = '0' and 
			   tipo <> '4' and
			   tipo_atu = '1' and
			   (( @Vatuforc = '0' )or 
			   ( @Vatuforc = '1' and @Vdatforc is null ) or
			   ( @Vatuforc = '1' and identif > CONVERT(char(14), 'YYMMDDHH24MISS', 03)))
		   group by 
			   numserial
		   order by 3) as abc

		if  @@rowcount = 0 
		begin
			GOTO Main_Loop 
		end 
	
		set rowcount 0			
		insert into pend_on003 ( end_ip, numserial, identif ) 
		    select distinct end_ip, numserial, identif from tmp_listapendencia ;
		select @ERR = @@ERROR
		if (@ERR <> 0) begin
			GOTO Main_Loop 
		end
		
		-- altera status das pendncias como tratadas em PEND_ON001
		declare @VEND_IP1 char(15)
		declare @VNUMSERIAL1 char(10)
		declare @VIDENTIF1 char(14)
		DECLARE SOBJ1 CURSOR FOR (select END_IP,NUMSERIAL,IDENTIF from tmp_listapendencia )
		OPEN SOBJ1
		fetch next from SOBJ1 into @VEND_IP1, @VNUMSERIAL1, @VIDENTIF1
		while (@@fetch_status <> -1)
		begin
			update PEND_ON001 
			set 
				status = '1' 
			where 
				numserial = @VNUMSERIAL1 and 
				end_ip = @VEND_IP1 and 
				identif <= @VIDENTIF1 AND
				tipo_atu = '1' and
				status = '0'  	    	  

			fetch next from SOBJ1 into @VEND_IP1, @VNUMSERIAL1, @VIDENTIF1
		end
		CLOSE SOBJ1
		DEALLOCATE SOBJ1

		-- sinaliza ao Conex a carga de Lista Pendencia Online
		update pend_on002ON set status = '1' where end_ip in ( select distinct end_ip from tmp_listapendencia )
		--update pend_on002ON set status = '1' where end_ip = @Vend_ip1
		select @ERR = @@ERROR

	Main_Loop:
		delete tmp_listapendencia 
		fetch next from SOBJ into @Vend_ip ,@Vqtd_livre ,@Vstatus ,@Vatuforc ,@Vdatforc 
	END

	CLOSE SOBJ
	DEALLOCATE SOBJ
	SET LOCK_TIMEOUT -1
END

GO

--grant execute on sp_criarlistapendencia  to ACE_USU
--GO

==> SCA_SQL_41.10.05.zip: sp2A_criarlistapendencia.sql <==
drop procedure sp2_criarlistapendencia 
go
create PROCEDURE sp2_criarlistapendencia 
--@nResto int 
AS
BEGIN
DECLARE  @MAXLIST INTEGER
DECLARE  @QTDELIST INTEGER
DECLARE  @QTDE_IN_LISTA INTEGER
DECLARE  @rstatus CHAR(1)
DECLARE @ERR INT


--	if @nResto = 1
--		return
		
	exec TELESSVR.sql_logenvon2A	
	SET @MAXLIST = 85
	SET LOCK_TIMEOUT 2000
	update pend_on002ON set status = '4' 
		where (status = '2' or status = '4') and data_ini + ( 1 / 24 / 60 )  < getdate() 

	DECLARE SOBJ CURSOR FOR (
		select distinct p.end_ip, p.qtd_livre, p.status , d.atuforc, d.datforc
		from 
			PEND_ON002ON p, DAT07 d 
		where 
			--(CAST (SUBSTRING (p.end_ip, 13, 3) AS INT) % 2) = @nResto and 
			p.end_ip = d.end_ip and 
			p.status = '0' and 
			p.qtd_livre > 0 and
			( exists ( select top 1 1 from pend_on001 where end_ip = p.end_ip and tipo_atu = '1' and status = '0' )
			or exists ( select top 1 1 from pend_on003 where end_ip = p.end_ip)))

	declare @Vend_ip char(15)
	declare @Vqtd_livre integer
	declare @Vstatus char(1)
	declare @Vatuforc char(1)
	declare @Vdatforc datetime


	OPEN SOBJ
	fetch next from SOBJ into @Vend_ip ,@Vqtd_livre ,@Vstatus ,@Vatuforc ,@Vdatforc 
	while (@@fetch_status <> -1)
	begin
		--begin transaction t2
		set @QTDE_IN_LISTA = (select count(*) from pend_on003 where end_ip = @Vend_ip)
		if @QTDE_IN_LISTA > 0 
		begin
			update pend_on002ON set status = '1' where end_ip = @Vend_ip
			select @ERR = @@ERROR
			GOTO Main_Loop 
		end
    	if @Vqtd_livre < @MAXLIST
        	set @QTDELIST = @Vqtd_livre 
		else
    	    set @QTDELIST = @MAXLIST
	
		set rowcount @QTDELIST
		insert into tmp_listapendencia ( end_ip, numserial, identif )
		select 
			@Vend_ip as end_ip,         
			numserial, 
			identif
		from 
		   (select
			   top 85
			   numserial, 
			   max( identif ) as identif,
			   min( identif ) as minidentif
		   from 
			   pend_on001 
		   where 
			   end_ip = @Vend_ip and
			   status = '0' and 
			   tipo <> '4' and
			   tipo_atu = '1' and
			   (( @Vatuforc = '0' )or 
			   ( @Vatuforc = '1' and @Vdatforc is null ) or
			   ( @Vatuforc = '1' and identif > CONVERT(char(14), 'YYMMDDHH24MISS', 03)))
		   group by 
			   numserial
		   order by 3) as abc

		if  @@rowcount = 0 
		begin
			GOTO Main_Loop 
		end 
	
		set rowcount 0			
		insert into pend_on003 ( end_ip, numserial, identif ) 
		    select distinct end_ip, numserial, identif from tmp_listapendencia ;
		select @ERR = @@ERROR
		if (@ERR <> 0) begin
			GOTO Main_Loop 
		end
		
		-- altera status das pendncias como tratadas em PEND_ON001
		declare @Vend_ip1 char(15)
		declare @VNUMSERIAL1 char(10)
		declare @VIDENTIF1 char(14)
		DECLARE SOBJ1 CURSOR FOR (select END_IP,NUMSERIAL,IDENTIF from tmp_listapendencia )
		OPEN SOBJ1
		fetch next from SOBJ1 into @Vend_ip1, @VNUMSERIAL1, @VIDENTIF1
		while (@@fetch_status <> -1)
		begin
			update PEND_ON001 
			set 
				status = '1' 
			where 
				numserial = @VNUMSERIAL1 and 
				end_ip = @Vend_ip1 and 
				identif <= @VIDENTIF1 AND
				tipo_atu = '1' and
				status = '0'  	    	  

			fetch next from SOBJ1 into @Vend_ip1, @VNUMSERIAL1, @VIDENTIF1
		end
		CLOSE SOBJ1
		DEALLOCATE SOBJ1

		-- sinaliza ao Conex a carga de Lista Pendencia Online
		update pend_on002ON set status = '1' where end_ip in ( select distinct end_ip from tmp_listapendencia )
		--update pend_on002ON set status = '1' where end_ip = @Vend_ip1
		select @ERR = @@ERROR

	Main_Loop:
		delete tmp_listapendencia 
		fetch next from SOBJ into @Vend_ip ,@Vqtd_livre ,@Vstatus ,@Vatuforc ,@Vdatforc 
	END

	CLOSE SOBJ
	DEALLOCATE SOBJ
	SET LOCK_TIMEOUT -1
END

GO

--grant execute on sp_criarlistapendencia  to ACE_USU
--GO
